@@ -2,8 +2,7 @@
 __name__ = 'sgmarkets_plot'
 name_url = __name__.replace('_', '-')
 
-__packages__ = [__name__]
-__version__ = '0.1.6'
+__version__ = '0.1.11'
 __description__ = 'sgmarket api plot helper'
 __long_description__ = 'See repo README'
 __author__ = 'sgmarkets'
@@ -23,3 +22,4 @@ __classifiers__ = ['Development Status :: 4 - Beta',
 __include_package_data__ = True
 __package_data__ = {}
 __zip_safe__ = False
+__entry_points__ = {}
